@@ -16,6 +16,14 @@ def option(*param_decls, cls=None, group=None, **kwargs):
     """Attaches an ``Option`` to the command.
     Refer to :class:`click.Option` and :class:`click.Parameter` for more info
     about the accepted parameters.
+
+    In your IDE, you won't see arguments that has to do with shell completion,
+    because they are different in Click 7 and 8 (both supported by Cloup):
+
+    - in Click 7, it's ``autocompletion``
+    - in Click 8, it's ``shell_complete``.
+
+    These arguments have different semantics, refer to Click's docs.
     """
     if cls is None:
         cls = GroupedOption
