@@ -1,6 +1,6 @@
 """
-This module defines the classes that support the styling and theming of commands
-help page.
+This module contains components that specifically address the styling and theming
+of the --help output.
 """
 import dataclasses as dc
 from typing import Callable, NamedTuple, Optional
@@ -89,7 +89,6 @@ class HelpTheme(NamedTuple):
             heading=Style(fg='bright_white', bold=True),
             constraint=Style(fg='magenta'),
             col1=Style(fg='bright_yellow'),
-            epilog=Style(fg='bright_white'),
         )
 
     @staticmethod
@@ -100,7 +99,6 @@ class HelpTheme(NamedTuple):
             heading=Style(fg='bright_blue'),
             constraint=Style(fg='red'),
             col1=Style(fg='yellow'),
-            epilog=Style(fg='bright_black'),
         )
 
 
