@@ -11,11 +11,13 @@ class _Missing(Enum):
 
 
 MISSING = _Missing.flag
-"""Singleton that indicates a missing value to use when None can't be used."""
+"""Singleton that works as a placeholder for a missing value. Useful when None
+can't be used to play the role because it represents a valid non-null value."""
 
 _T = TypeVar('_T')
 Possibly = Union[_Missing, _T]
-"""Possibly[T] is MISSING or a value of type T."""
+"""Possibly[T] is meant to be used in place of Optional[T] when None can't be
+used to represent a missing value."""
 
 F = TypeVar('F', bound=Callable)
 """Type variable for a Callable."""
