@@ -4,13 +4,14 @@ from unittest.mock import Mock
 import click
 import pytest
 from click import Argument, Option
-from pytest import mark
 
 import cloup
-from cloup import ConstraintMixin
-from cloup.constraints import Constraint
+from cloup import ConstraintMixin, Context
+from cloup._util import pick_non_missing
+from cloup.typing import MISSING
+from cloup.constraints import Constraint, RequireAtLeast, mutually_exclusive
 from tests.constraints.test_constraints import FakeConstraint
-from tests.util import noop
+from tests.util import new_dummy_func, pick_first_bool
 
 
 class Cmd(ConstraintMixin, click.Command):
@@ -24,7 +25,7 @@ class TestConstraintMixin:
             Option(('--str-opt',)),
             Option(('--int-opt', 'option2')),
         ]
-        cmd = Cmd(name='cmd', params=params, callback=noop)
+        cmd = Cmd(name='cmd', params=params, callback=new_dummy_func())
         for param in params:
             assert cmd.get_param_by_name(param.name) == param
 
@@ -34,30 +35,29 @@ class TestConstraintMixin:
         assert cmd.get_params_by_name(['arg1', 'option2']) == (params[0], params[2])
 
 
-@mark.parametrize(
+@pytest.mark.parametrize(
     'do_check_consistency', [True, False],
     ids=['with_consistency_checks', 'without_consistency_checks']
 )
 def test_constraints_are_checked_according_to_protocol(runner, do_check_consistency):
     constraints = [
-        Mock(spec_set=Constraint, wraps=FakeConstraint()),
-        Mock(spec_set=Constraint, wraps=FakeConstraint()),
-        Mock(spec_set=Constraint, wraps=FakeConstraint()),
+        Mock(spec_set=Constraint, wraps=FakeConstraint())
+        for _ in range(3)
     ]
+    settings = Context.settings(check_constraints_consistency=do_check_consistency)
 
-    @cloup.command()
+    @cloup.command(context_settings=settings)
     @cloup.option_group('first', cloup.option('--a'), cloup.option('--b'),
                         constraint=constraints[0])
     @cloup.option_group('second', cloup.option('--c'), cloup.option('--d'),
                         constraint=constraints[1])
     @cloup.constraint(constraints[2], ['a', 'c'])
-    def cmd(a, b, c, d):
+    @cloup.pass_context
+    def cmd(ctx, a, b, c, d):
+        assert Constraint.must_check_consistency(ctx) == do_check_consistency
         print(f'{a}, {b}, {c}, {d}')
 
-    with Constraint.consistency_checks_toggled(do_check_consistency):
-        assert Constraint.must_check_consistency() == do_check_consistency
-        result = runner.invoke(cmd, args='--a=1 --c=2'.split(),
-                               catch_exceptions=False)
+    result = runner.invoke(cmd, args='--a=1 --c=2'.split())
 
     assert result.output.strip() == '1, None, 2, None'
     for constr, opt_names in zip(constraints, [['a', 'b'], ['c', 'd'], ['a', 'c']]):
@@ -69,27 +69,28 @@ def test_constraints_are_checked_according_to_protocol(runner, do_check_consiste
         constr.check_values.assert_called_once()
 
 
-@mark.parametrize('ctx_show_constraints', [None, True, False])
-@mark.parametrize('show_constraints', [None, True, False])
+@pytest.mark.parametrize(
+    'cmd_value', [MISSING, None, True, False],
+    ids=lambda val: f'cmd_{val}'
+)
+@pytest.mark.parametrize(
+    'ctx_value', [MISSING, None, True, False],
+    ids=lambda val: f'ctx_{val}'
+)
 def test_constraints_are_shown_in_help_only_if_feature_is_enabled(
-    runner, show_constraints, ctx_show_constraints
+    runner, cmd_value, ctx_value
 ):
-    # The default is False
-    should_show_constraints = False
-    # The context parameter overrides the default (if not None)
-    if ctx_show_constraints is not None:
-        should_show_constraints = ctx_show_constraints
-    # The command parameter overrides the context value (if not None)
-    if show_constraints is not None:
-        should_show_constraints = show_constraints
+    should_show = pick_first_bool([cmd_value, ctx_value], default=False)
+    cxt_settings = pick_non_missing(dict(
+        show_constraints=ctx_value,
+        terminal_width=80,
+    ))
+    cmd_kwargs = pick_non_missing(dict(
+        show_constraints=cmd_value,
+        context_settings=cxt_settings
+    ))
 
-    @cloup.command(
-        show_constraints=show_constraints,
-        context_settings={
-            'show_constraints': ctx_show_constraints,
-            'terminal_width': 80,
-        }
-    )
+    @cloup.command(**cmd_kwargs)
     @cloup.option('--a')
     @cloup.option('--b')
     @cloup.option('--c')
@@ -103,7 +104,7 @@ def test_constraints_are_shown_in_help_only_if_feature_is_enabled(
                            prog_name='test')
     out = result.output.strip()
 
-    if should_show_constraints:
+    if should_show:
         expected = textwrap.dedent('''
             Usage: test [OPTIONS]
 
@@ -129,3 +130,31 @@ def test_constraints_are_shown_in_help_only_if_feature_is_enabled(
               --help    Show this message and exit.
         ''').strip()
         assert out == expected
+
+
+def test_usage_of_constraints_as_decorators(runner):
+    require_any = RequireAtLeast(1)
+
+    @cloup.command()
+    @require_any(
+        cloup.argument('arg', required=False),
+        cloup.option('-a'),
+        cloup.option('-b'),
+    )
+    @mutually_exclusive(
+        cloup.option('-c'),
+        cloup.option('-d'),
+    )
+    def cmd(arg, a, b, c, d):
+        pass
+
+    assert runner.invoke(cmd, args='ARG -c CCC'.split()).exit_code == 0
+    assert runner.invoke(cmd, args='-a AAA -d DDD'.split()).exit_code == 0
+
+    res = runner.invoke(cmd, args=[])
+    assert res.exit_code == click.UsageError.exit_code
+    assert 'at least 1 of the following' in res.output
+
+    res = runner.invoke(cmd, args='ARG -c CCC -d DDD'.split())
+    assert res.exit_code == click.UsageError.exit_code
+    assert 'mutually exclusive' in res.output
